window.Gleam.initSearch([{"doc":"glyph","title":"glyph","content":"# Glyph\n\nI am primarily writing this to learn Gleam + the BEAM ecosystem, though I do plan on fully implementing all features.\n\nI do not recommend using this for a &quot;real&quot; bot just yet - there&#39;s still many missing events and it is not prepared for highly available bots yet.\n\nI _do_ recommend using this if you just want to play around with it and maybe even contribute!\n\n## Roadmap\n\nTo see what is planned for a certain release, go to the Issues section and filter by Milestone.\n\n[![Package Version](https://img.shields.io/hexpm/v/glyph)](https://hex.pm/packages/glyph)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glyph/)\n\n## Add Glyph to your project\n\n```sh\ngleam add glyph\n```\n\n## Basic Ping-Pong example\n\nThe following code sets up a bot that _replies_ to `!ping` with `Pong!` and `!pong` with `Ping!`.\n\nNote: any code related to the `logging` package below is not necessary, but may help us debug if you encounter issues.\n\n```gleam\nimport envoy\nimport gleam/erlang/process\nimport glyph/clients/bot\nimport glyph/models/discord\nimport logging\n\npub type LogLevel {\n  Debug\n}\n\npub type Log {\n  Level\n}\n\n@external(erlang, &quot;logger&quot;, &quot;set_primary_config&quot;)\nfn set_logger_level(log: Log, level: LogLevel) -&gt; Nil\n\npub fn main() {\n  logging.configure()\n  set_logger_level(Level, Debug)\n\n  let assert Ok(discord_token) = envoy.get(&quot;DISCORD_TOKEN&quot;)\n  let bot_name = &quot;YOUR_BOT_NAME&quot;\n  let bot_version = &quot;YOUR_BOT_VERSION&quot;\n\n  // Create a new bot and register its handlers\n  let assert Ok(bot) =\n    bot.new(discord_token, bot_name, bot_version)\n    |&gt; bot.set_intents([discord.GuildMessages, discord.MessageContent])\n    |&gt; bot.on_message_create(message_create_callback)\n    |&gt; bot.initialize\n\n  process.sleep_forever()\n}\n\nfn pong(bot: discord.BotClient, msg: discord.Message) {\n  let response = \n    message.new()\n    |&gt; message.content(&quot;Pong!&quot;)\n    |&gt; message.reply_to(msg)\n  \n  let _ = bot.send(bot, msg.channel_id, response)\n\n  Nil\n}\n\nfn ping(bot: discord.BotClient, msg: discord.Message) {\n  let response = \n    message.new()\n    |&gt; message.content(&quot;Ping!&quot;)\n    |&gt; message.reply_to(msg)\n  \n  let _ = bot.send(bot, msg.channel_id, response)\n\n  Nil\n}\n\npub fn message_create_handler(\n  bot: discord.BotClient,\n  msg: discord.Message,\n) -&gt; Result(Nil, discord.DiscordError) {\n  case string.starts_with(msg.content, &quot;!ping&quot;) {\n    True -&gt; pong(bot, msg)\n    False -&gt; Nil\n  }\n\n  case string.starts_with(msg.content, &quot;!pong&quot;) {\n    True -&gt; ping(bot, msg)\n    False -&gt; Nil\n  }\n\n  Ok(Nil)\n}\n```\n\n## Advanced Examples\n\nAs I develop Glyph, I will do my best to keep [Scribe](https://github.com/grottohub/scribe/) up to date with examples for all supported features.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glyph&gt;.\n","url":"index.html"},{"doc":"glyph/models/discord","title":"AllowedMentions","content":"pub type AllowedMentions {\n  AllowedMentions(\n    parse: List(MentionType),\n    roles: List(Snowflake),\n    users: List(Snowflake),\n    replied_user: Bool,\n  )\n}\n This contains information regarding the mentions contained within\n a message&#39;s content.\nAllowedMentions(\n  parse: List(MentionType),\n  roles: List(Snowflake),\n  users: List(Snowflake),\n  replied_user: Bool,\n)\n\n\nSynonyms:\nglyph/models/discord.AllowedMentions\nglyph/models/discord AllowedMentions","url":"glyph/models/discord.html#AllowedMentions"},{"doc":"glyph/models/discord","title":"Application","content":"pub type Application {\n  Application(\n    id: Snowflake,\n    name: String,\n    icon: Option(String),\n    description: String,\n    rpc_origins: Option(List(String)),\n    bot_public: Bool,\n    bot_require_code_grant: Bool,\n    bot: Option(Bot),\n    terms_of_service_url: Option(String),\n    privacy_policy_url: Option(String),\n    owner: Option(Owner),\n    summary: Option(String),\n    verify_key: String,\n    team: Option(Team),\n    guild_id: Option(Snowflake),\n    primary_sku_id: Option(Snowflake),\n    slug: Option(String),\n    cover_image: Option(String),\n    flags: Option(Int),\n    approximate_guild_count: Option(Int),\n    redirect_uris: Option(List(String)),\n    interactions_endpoint_url: Option(String),\n    role_connections_verification_url: Option(String),\n    tags: Option(List(String)),\n    install_params: Option(InstallParams),\n    custom_install_url: Option(String),\n  )\n}\n Model for a Discord [Application](https://discord.com/developers/docs/resources/application).\n \n TODO: summary is deprecated and will be removed in v11\nApplication(\n  id: Snowflake,\n  name: String,\n  icon: Option(String),\n  description: String,\n  rpc_origins: Option(List(String)),\n  bot_public: Bool,\n  bot_require_code_grant: Bool,\n  bot: Option(Bot),\n  terms_of_service_url: Option(String),\n  privacy_policy_url: Option(String),\n  owner: Option(Owner),\n  summary: Option(String),\n  verify_key: String,\n  team: Option(Team),\n  guild_id: Option(Snowflake),\n  primary_sku_id: Option(Snowflake),\n  slug: Option(String),\n  cover_image: Option(String),\n  flags: Option(Int),\n  approximate_guild_count: Option(Int),\n  redirect_uris: Option(List(String)),\n  interactions_endpoint_url: Option(String),\n  role_connections_verification_url: Option(String),\n  tags: Option(List(String)),\n  install_params: Option(InstallParams),\n  custom_install_url: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.Application\nglyph/models/discord Application","url":"glyph/models/discord.html#Application"},{"doc":"glyph/models/discord","title":"Bot","content":"pub type Bot =\n  User\n\n\nSynonyms:\nglyph/models/discord.Bot\nglyph/models/discord Bot","url":"glyph/models/discord.html#Bot"},{"doc":"glyph/models/discord","title":"BotClient","content":"pub type BotClient {\n  BotClient(\n    token_type: rest.TokenType,\n    token: String,\n    client_url: String,\n    client_version: String,\n    intents: Int,\n    handlers: EventHandler,\n    rest_client: rest.RESTClient,\n  )\n}\n Type that contains necessary information when communicating with the Discord API\nBotClient(\n  token_type: rest.TokenType,\n  token: String,\n  client_url: String,\n  client_version: String,\n  intents: Int,\n  handlers: EventHandler,\n  rest_client: rest.RESTClient,\n)\n\n\nSynonyms:\nglyph/models/discord.BotClient\nglyph/models/discord BotClient","url":"glyph/models/discord.html#BotClient"},{"doc":"glyph/models/discord","title":"DiscordError","content":"pub type DiscordError\n Generic Discord Error\n\nSynonyms:\nglyph/models/discord.DiscordError\nglyph/models/discord DiscordError","url":"glyph/models/discord.html#DiscordError"},{"doc":"glyph/models/discord","title":"Embed","content":"pub type Embed {\n  Embed(\n    title: Option(String),\n    description: Option(String),\n    url: Option(String),\n    timestamp: Option(String),\n    color: Option(Int),\n    footer: Option(EmbedFooter),\n    image: Option(EmbedImage),\n    thumbnail: Option(EmbedThumbnail),\n    video: Option(EmbedVideo),\n    provider: Option(EmbedProvider),\n    author: Option(EmbedAuthor),\n    fields: Option(List(EmbedField)),\n  )\n}\n Model for an [embed](https://discord.com/developers/docs/resources/channel#embed-object) that can be\n attached to a message.\nEmbed(\n  title: Option(String),\n  description: Option(String),\n  url: Option(String),\n  timestamp: Option(String),\n  color: Option(Int),\n  footer: Option(EmbedFooter),\n  image: Option(EmbedImage),\n  thumbnail: Option(EmbedThumbnail),\n  video: Option(EmbedVideo),\n  provider: Option(EmbedProvider),\n  author: Option(EmbedAuthor),\n  fields: Option(List(EmbedField)),\n)\n\n\nSynonyms:\nglyph/models/discord.Embed\nglyph/models/discord Embed","url":"glyph/models/discord.html#Embed"},{"doc":"glyph/models/discord","title":"EmbedAuthor","content":"pub type EmbedAuthor {\n  EmbedAuthor(\n    name: String,\n    url: Option(String),\n    icon_url: Option(String),\n    proxy_icon_url: Option(String),\n  )\n}\n Metadata about the author of the embedded data.\nEmbedAuthor(\n  name: String,\n  url: Option(String),\n  icon_url: Option(String),\n  proxy_icon_url: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.EmbedAuthor\nglyph/models/discord EmbedAuthor","url":"glyph/models/discord.html#EmbedAuthor"},{"doc":"glyph/models/discord","title":"EmbedField","content":"pub type EmbedField {\n  EmbedField(name: String, value: String, inline: Option(Bool))\n}\n Generic fields that can be added to an embed.\nEmbedField(name: String, value: String, inline: Option(Bool))\n\n\nSynonyms:\nglyph/models/discord.EmbedField\nglyph/models/discord EmbedField","url":"glyph/models/discord.html#EmbedField"},{"doc":"glyph/models/discord","title":"EmbedFooter","content":"pub type EmbedFooter {\n  EmbedFooter(\n    text: String,\n    icon_url: Option(String),\n    proxy_icon_url: Option(String),\n  )\n}\n Supported information for an embed&#39;s footer.\nEmbedFooter(\n  text: String,\n  icon_url: Option(String),\n  proxy_icon_url: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.EmbedFooter\nglyph/models/discord EmbedFooter","url":"glyph/models/discord.html#EmbedFooter"},{"doc":"glyph/models/discord","title":"EmbedImage","content":"pub type EmbedImage {\n  EmbedImage(\n    url: String,\n    proxy_url: Option(String),\n    height: Option(Int),\n    width: Option(Int),\n  )\n}\n The information necessary to send an image with an embed.\nEmbedImage(\n  url: String,\n  proxy_url: Option(String),\n  height: Option(Int),\n  width: Option(Int),\n)\n\n\nSynonyms:\nglyph/models/discord.EmbedImage\nglyph/models/discord EmbedImage","url":"glyph/models/discord.html#EmbedImage"},{"doc":"glyph/models/discord","title":"EmbedProvider","content":"pub type EmbedProvider {\n  EmbedProvider(name: Option(String), url: Option(String))\n}\n Metadata about the source of the embedded data.\nEmbedProvider(name: Option(String), url: Option(String))\n\n\nSynonyms:\nglyph/models/discord.EmbedProvider\nglyph/models/discord EmbedProvider","url":"glyph/models/discord.html#EmbedProvider"},{"doc":"glyph/models/discord","title":"EmbedThumbnail","content":"pub type EmbedThumbnail {\n  EmbedThumbnail(\n    url: String,\n    proxy_url: Option(String),\n    height: Option(Int),\n    width: Option(Int),\n  )\n}\n The information necessary to send a thumbnail with an embed.\nEmbedThumbnail(\n  url: String,\n  proxy_url: Option(String),\n  height: Option(Int),\n  width: Option(Int),\n)\n\n\nSynonyms:\nglyph/models/discord.EmbedThumbnail\nglyph/models/discord EmbedThumbnail","url":"glyph/models/discord.html#EmbedThumbnail"},{"doc":"glyph/models/discord","title":"EmbedVideo","content":"pub type EmbedVideo {\n  EmbedVideo(\n    url: Option(String),\n    proxy_url: Option(String),\n    height: Option(Int),\n    width: Option(Int),\n  )\n}\n The information necessary to send a video with an embed.\nEmbedVideo(\n  url: Option(String),\n  proxy_url: Option(String),\n  height: Option(Int),\n  width: Option(Int),\n)\n\n\nSynonyms:\nglyph/models/discord.EmbedVideo\nglyph/models/discord EmbedVideo","url":"glyph/models/discord.html#EmbedVideo"},{"doc":"glyph/models/discord","title":"EventHandler","content":"pub type EventHandler {\n  EventHandler(\n    on_message_create: fn(BotClient, Message) -&gt;\n      Result(Nil, DiscordError),\n  )\n}\n These represent Glyph&#39;s supported gateway events and the necessary function signature\n for callbacks that get passed in to the `BotClient`.\nEventHandler(\n  on_message_create: fn(BotClient, Message) -&gt;\n    Result(Nil, DiscordError),\n)\n\n\nSynonyms:\nglyph/models/discord.EventHandler\nglyph/models/discord EventHandler","url":"glyph/models/discord.html#EventHandler"},{"doc":"glyph/models/discord","title":"GatewayEvent","content":"pub type GatewayEvent {\n  GatewayEvent(\n    op: Int,\n    d: dynamic.Dynamic,\n    s: Option(Int),\n    t: Option(String),\n  )\n}\n Top-level structure of [payloads](https://discord.com/developers/docs/topics/gateway-events#payload-structure) between gateway and client.\nGatewayEvent(\n  op: Int,\n  d: dynamic.Dynamic,\n  s: Option(Int),\n  t: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.GatewayEvent\nglyph/models/discord GatewayEvent","url":"glyph/models/discord.html#GatewayEvent"},{"doc":"glyph/models/discord","title":"GatewayIntent","content":"pub type GatewayIntent {\n  Guilds\n  GuildMembers\n  GuildModeration\n  GuildEmojisAndStickers\n  GuildIntegrations\n  GuildWebhooks\n  GuildInvites\n  GuildVoiceStates\n  GuildPresences\n  GuildMessages\n  GuildMessageReactions\n  GuildMessageTyping\n  DirectMessages\n  DirectMessageReactions\n  DirectMessageTyping\n  MessageContent\n  GuildScheduledEvents\n  AutoModerationConfiguration\n  AutoModerationExecution\n}\n The following are [gateway intents](https://discord.com/developers/docs/topics/gateway#gateway-intents) which represent what events you subscribe to.\nGuilds\n\n\nGuildMembers\n\n\nGuildModeration\n\n\nGuildEmojisAndStickers\n\n\nGuildIntegrations\n\n\nGuildWebhooks\n\n\nGuildInvites\n\n\nGuildVoiceStates\n\n\nGuildPresences\n\n\nGuildMessages\n\n\nGuildMessageReactions\n\n\nGuildMessageTyping\n\n\nDirectMessages\n\n\nDirectMessageReactions\n\n\nDirectMessageTyping\n\n\nMessageContent\n\n\nGuildScheduledEvents\n\n\nAutoModerationConfiguration\n\n\nAutoModerationExecution\n\n\nSynonyms:\nglyph/models/discord.GatewayIntent\nglyph/models/discord GatewayIntent","url":"glyph/models/discord.html#GatewayIntent"},{"doc":"glyph/models/discord","title":"GetGatewayBot","content":"pub type GetGatewayBot {\n  GetGatewayBot(\n    url: String,\n    shards: Int,\n    session_start_limit: SessionStartLimit,\n  )\n}\n Model for the [response](https://discord.com/developers/docs/topics/gateway#get-gateway-bot) received from `/gateway/bot`.\nGetGatewayBot(\n  url: String,\n  shards: Int,\n  session_start_limit: SessionStartLimit,\n)\n\n\nSynonyms:\nglyph/models/discord.GetGatewayBot\nglyph/models/discord GetGatewayBot","url":"glyph/models/discord.html#GetGatewayBot"},{"doc":"glyph/models/discord","title":"HelloEvent","content":"pub type HelloEvent {\n  HelloEvent(heartbeat_interval: Int)\n}\n Structure of a [Hello](https://discord.com/developers/docs/topics/gateway#hello-event) event.\nHelloEvent(heartbeat_interval: Int)\n\n\nSynonyms:\nglyph/models/discord.HelloEvent\nglyph/models/discord HelloEvent","url":"glyph/models/discord.html#HelloEvent"},{"doc":"glyph/models/discord","title":"InstallParams","content":"pub type InstallParams {\n  InstallParams(scopes: List(String), permissions: String)\n}\n Model for [Install Params](https://discord.com/developers/docs/resources/application#install-params-object).\nInstallParams(scopes: List(String), permissions: String)\n\n\nSynonyms:\nglyph/models/discord.InstallParams\nglyph/models/discord InstallParams","url":"glyph/models/discord.html#InstallParams"},{"doc":"glyph/models/discord","title":"Member","content":"pub type Member {\n  Member(\n    membership_state: Int,\n    team_id: Snowflake,\n    user: User,\n    role: String,\n  )\n}\n Model for a [Team Member](https://discord.com/developers/docs/topics/teams#data-models-team-member-object) object.\nMember(\n  membership_state: Int,\n  team_id: Snowflake,\n  user: User,\n  role: String,\n)\n\n\nSynonyms:\nglyph/models/discord.Member\nglyph/models/discord Member","url":"glyph/models/discord.html#Member"},{"doc":"glyph/models/discord","title":"MembershipState","content":"pub type MembershipState {\n  INVITED\n  ACCEPTED\n}\n Model for [Membership State](https://discord.com/developers/docs/topics/teams#data-models-membership-state-enum).\nINVITED\n\n\nACCEPTED\n\n\nSynonyms:\nglyph/models/discord.MembershipState\nglyph/models/discord MembershipState","url":"glyph/models/discord.html#MembershipState"},{"doc":"glyph/models/discord","title":"MentionType","content":"pub type MentionType {\n  Roles\n  Users\n  Everyone\n}\n The supported types of mentions.\nRoles\n\n\nUsers\n\n\nEveryone\n\n\nSynonyms:\nglyph/models/discord.MentionType\nglyph/models/discord MentionType","url":"glyph/models/discord.html#MentionType"},{"doc":"glyph/models/discord","title":"Message","content":"pub type Message {\n  Message(\n    id: Snowflake,\n    channel_id: Snowflake,\n    author: User,\n    content: String,\n    tts: Bool,\n    mention_everyone: Bool,\n    pinned: Bool,\n    message_type: Int,\n  )\n}\n Model for a [Message](https://discord.com/developers/docs/resources/channel#message-object) object as received from the gateway.\n \n TODO: add remaining fields\nMessage(\n  id: Snowflake,\n  channel_id: Snowflake,\n  author: User,\n  content: String,\n  tts: Bool,\n  mention_everyone: Bool,\n  pinned: Bool,\n  message_type: Int,\n)\n\n\nSynonyms:\nglyph/models/discord.Message\nglyph/models/discord Message","url":"glyph/models/discord.html#Message"},{"doc":"glyph/models/discord","title":"MessagePayload","content":"pub type MessagePayload {\n  MessagePayload(\n    content: Option(String),\n    tts: Option(Bool),\n    embeds: Option(List(Embed)),\n    allowed_mentions: Option(AllowedMentions),\n    message_reference: Option(MessageReference),\n    sticker_ids: Option(List(Snowflake)),\n    flags: Option(Int),\n    nonce: Option(String),\n    enforce_nonce: Option(Bool),\n  )\n}\n Model for the [payload](https://discord.com/developers/docs/resources/channel#create-message) when creating a message.\n \n TODO: message components (will come w/ interactions / commands), files\nMessagePayload(\n  content: Option(String),\n  tts: Option(Bool),\n  embeds: Option(List(Embed)),\n  allowed_mentions: Option(AllowedMentions),\n  message_reference: Option(MessageReference),\n  sticker_ids: Option(List(Snowflake)),\n  flags: Option(Int),\n  nonce: Option(String),\n  enforce_nonce: Option(Bool),\n)\n\n\nSynonyms:\nglyph/models/discord.MessagePayload\nglyph/models/discord MessagePayload","url":"glyph/models/discord.html#MessagePayload"},{"doc":"glyph/models/discord","title":"MessageReference","content":"pub type MessageReference {\n  MessageReference(\n    message_id: Option(Snowflake),\n    channel_id: Option(Snowflake),\n    guild_id: Option(Snowflake),\n    fail_if_not_exists: Option(Bool),\n  )\n}\n This contains information needed for a `message_reference` attached\n to a `MessagePayload`. Needed when replying to a message.\nMessageReference(\n  message_id: Option(Snowflake),\n  channel_id: Option(Snowflake),\n  guild_id: Option(Snowflake),\n  fail_if_not_exists: Option(Bool),\n)\n\n\nSynonyms:\nglyph/models/discord.MessageReference\nglyph/models/discord MessageReference","url":"glyph/models/discord.html#MessageReference"},{"doc":"glyph/models/discord","title":"Owner","content":"pub type Owner =\n  User\n\n\nSynonyms:\nglyph/models/discord.Owner\nglyph/models/discord Owner","url":"glyph/models/discord.html#Owner"},{"doc":"glyph/models/discord","title":"ReadyApplication","content":"pub type ReadyApplication {\n  ReadyApplication(id: Snowflake, flags: Int)\n}\n Model for a partial Application received in the Ready event\nReadyApplication(id: Snowflake, flags: Int)\n\n\nSynonyms:\nglyph/models/discord.ReadyApplication\nglyph/models/discord ReadyApplication","url":"glyph/models/discord.html#ReadyApplication"},{"doc":"glyph/models/discord","title":"ReadyEvent","content":"pub type ReadyEvent {\n  ReadyEvent(\n    v: Int,\n    user: User,\n    guilds: dynamic.Dynamic,\n    session_id: String,\n    resume_gateway_url: String,\n    shard: Option(List(Int)),\n    application: ReadyApplication,\n  )\n}\n Structure of a [Ready](https://discord.com/developers/docs/topics/gateway-events#ready-ready-event-fields) event.\nReadyEvent(\n  v: Int,\n  user: User,\n  guilds: dynamic.Dynamic,\n  session_id: String,\n  resume_gateway_url: String,\n  shard: Option(List(Int)),\n  application: ReadyApplication,\n)\n\n\nSynonyms:\nglyph/models/discord.ReadyEvent\nglyph/models/discord ReadyEvent","url":"glyph/models/discord.html#ReadyEvent"},{"doc":"glyph/models/discord","title":"SessionStartLimit","content":"pub type SessionStartLimit {\n  SessionStartLimit(\n    total: Int,\n    remaining: Int,\n    reset_after: Int,\n    max_concurrency: Int,\n  )\n}\n Model for [Session Start Limit Object](https://discord.com/developers/docs/topics/gateway#session-start-limit-object).\nSessionStartLimit(\n  total: Int,\n  remaining: Int,\n  reset_after: Int,\n  max_concurrency: Int,\n)\n\n\nSynonyms:\nglyph/models/discord.SessionStartLimit\nglyph/models/discord SessionStartLimit","url":"glyph/models/discord.html#SessionStartLimit"},{"doc":"glyph/models/discord","title":"Snowflake","content":"pub type Snowflake =\n  String\n The [data structure](https://discord.com/developers/docs/reference#snowflakes) Discord uses for UUIDs.\n\nSynonyms:\nglyph/models/discord.Snowflake\nglyph/models/discord Snowflake","url":"glyph/models/discord.html#Snowflake"},{"doc":"glyph/models/discord","title":"Team","content":"pub type Team {\n  Team(\n    id: Snowflake,\n    icon: Option(String),\n    members: List(Member),\n    name: String,\n    owner_user_id: Snowflake,\n  )\n}\n Model for a [Team](https://discord.com/developers/docs/topics/teams#data-models-team-object) object.\nTeam(\n  id: Snowflake,\n  icon: Option(String),\n  members: List(Member),\n  name: String,\n  owner_user_id: Snowflake,\n)\n\n\nSynonyms:\nglyph/models/discord.Team\nglyph/models/discord Team","url":"glyph/models/discord.html#Team"},{"doc":"glyph/models/discord","title":"User","content":"pub type User {\n  User(\n    id: Snowflake,\n    username: String,\n    discriminator: String,\n    global_name: Option(String),\n    avatar: Option(String),\n    bot: Option(Bool),\n    system: Option(Bool),\n    mfa_enabled: Option(Bool),\n    banner: Option(String),\n    accent_color: Option(Int),\n    locale: Option(String),\n    email: Option(String),\n    flags: Option(Int),\n    premium_type: Option(Int),\n    public_flags: Option(Int),\n    avatar_decoration: Option(String),\n  )\n}\n Model for a Discord [User](https://discord.com/developers/docs/resources/user#user-object).\n \n Some additional fields marked as optional here due to the use of partial user objects\n in other areas of the API.\nUser(\n  id: Snowflake,\n  username: String,\n  discriminator: String,\n  global_name: Option(String),\n  avatar: Option(String),\n  bot: Option(Bool),\n  system: Option(Bool),\n  mfa_enabled: Option(Bool),\n  banner: Option(String),\n  accent_color: Option(Int),\n  locale: Option(String),\n  email: Option(String),\n  flags: Option(Int),\n  premium_type: Option(Int),\n  public_flags: Option(Int),\n  avatar_decoration: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.User\nglyph/models/discord User","url":"glyph/models/discord.html#User"},{"doc":"glyph/models/discord","title":"mention_type_to_string","content":"pub fn mention_type_to_string(m: MentionType) -&gt; String\n\nSynonyms:\nglyph/models/discord.mention_type_to_string\nglyph/models/discord mention_type_to_string","url":"glyph/models/discord.html#mention_type_to_string"},{"doc":"glyph/models/discord","title":"glyph/models/discord","content":" This contains all types needed to communicate with either the Gateway or REST API.","url":"glyph/models/discord.html"},{"doc":"glyph/builders/embed","title":"EmbedColor","content":"pub type EmbedColor {\n  White\n  Greyple\n  Black\n  DarkButNotBlack\n  NotQuiteBlack\n  Blurple\n  Green\n  Yellow\n  Fuschia\n  Red\n}\n These are the colors of the official Discord palette\nWhite\n\n\nGreyple\n\n\nBlack\n\n\nDarkButNotBlack\n\n\nNotQuiteBlack\n\n\nBlurple\n\n\nGreen\n\n\nYellow\n\n\nFuschia\n\n\nRed\n\n\nSynonyms:\nglyph/builders/embed.EmbedColor\nglyph/builders/embed EmbedColor","url":"glyph/builders/embed.html#EmbedColor"},{"doc":"glyph/builders/embed","title":"author","content":"pub fn author(e: Embed, name: String) -&gt; Embed\n Set a name for an author\nSynonyms:\nglyph/builders/embed.author\nglyph/builders/embed author","url":"glyph/builders/embed.html#author"},{"doc":"glyph/builders/embed","title":"author_icon","content":"pub fn author_icon(e: Embed, icon_url: String) -&gt; Embed\n Set an icon URL for an author\nSynonyms:\nglyph/builders/embed.author_icon\nglyph/builders/embed author_icon","url":"glyph/builders/embed.html#author_icon"},{"doc":"glyph/builders/embed","title":"author_url","content":"pub fn author_url(e: Embed, url: String) -&gt; Embed\n Set a URL for an author\nSynonyms:\nglyph/builders/embed.author_url\nglyph/builders/embed author_url","url":"glyph/builders/embed.html#author_url"},{"doc":"glyph/builders/embed","title":"color","content":"pub fn color(e: Embed, color: EmbedColor) -&gt; Embed\n Set the embed color to one of the available options\nSynonyms:\nglyph/builders/embed.color\nglyph/builders/embed color","url":"glyph/builders/embed.html#color"},{"doc":"glyph/builders/embed","title":"description","content":"pub fn description(e: Embed, description: String) -&gt; Embed\n Set the description of the embed\nSynonyms:\nglyph/builders/embed.description\nglyph/builders/embed description","url":"glyph/builders/embed.html#description"},{"doc":"glyph/builders/embed","title":"field","content":"pub fn field(\n  e: Embed,\n  name: String,\n  value: String,\n  inline: Bool,\n) -&gt; Embed\n Add a new field to the embed\nSynonyms:\nglyph/builders/embed.field\nglyph/builders/embed field","url":"glyph/builders/embed.html#field"},{"doc":"glyph/builders/embed","title":"footer_icon_url","content":"pub fn footer_icon_url(e: Embed, icon_url: String) -&gt; Embed\n Set an icon URL for the embed&#39;s footer\nSynonyms:\nglyph/builders/embed.footer_icon_url\nglyph/builders/embed footer_icon_url","url":"glyph/builders/embed.html#footer_icon_url"},{"doc":"glyph/builders/embed","title":"footer_text","content":"pub fn footer_text(e: Embed, text: String) -&gt; Embed\n Set the text for the embed&#39;s footer\nSynonyms:\nglyph/builders/embed.footer_text\nglyph/builders/embed footer_text","url":"glyph/builders/embed.html#footer_text"},{"doc":"glyph/builders/embed","title":"image","content":"pub fn image(e: Embed, image_url: String) -&gt; Embed\n Set the source URL for an image\nSynonyms:\nglyph/builders/embed.image\nglyph/builders/embed image","url":"glyph/builders/embed.html#image"},{"doc":"glyph/builders/embed","title":"image_height","content":"pub fn image_height(e: Embed, height: Int) -&gt; Embed\n Set the height of the embedded image\nSynonyms:\nglyph/builders/embed.image_height\nglyph/builders/embed image_height","url":"glyph/builders/embed.html#image_height"},{"doc":"glyph/builders/embed","title":"image_width","content":"pub fn image_width(e: Embed, width: Int) -&gt; Embed\n Set the width of the embedded image\nSynonyms:\nglyph/builders/embed.image_width\nglyph/builders/embed image_width","url":"glyph/builders/embed.html#image_width"},{"doc":"glyph/builders/embed","title":"new","content":"pub fn new() -&gt; Embed\n Construct a new, empty Embed\nSynonyms:\nglyph/builders/embed.new\nglyph/builders/embed new","url":"glyph/builders/embed.html#new"},{"doc":"glyph/builders/embed","title":"provider","content":"pub fn provider(\n  e: Embed,\n  name: Option(String),\n  url: Option(String),\n) -&gt; Embed\n Set a name and URL for a provider (e.g. Twitch and https://twitch.tv)\nSynonyms:\nglyph/builders/embed.provider\nglyph/builders/embed provider","url":"glyph/builders/embed.html#provider"},{"doc":"glyph/builders/embed","title":"thumbnail","content":"pub fn thumbnail(e: Embed, thumbnail_url: String) -&gt; Embed\n Set the source URL for a thumbnail\nSynonyms:\nglyph/builders/embed.thumbnail\nglyph/builders/embed thumbnail","url":"glyph/builders/embed.html#thumbnail"},{"doc":"glyph/builders/embed","title":"thumbnail_height","content":"pub fn thumbnail_height(e: Embed, height: Int) -&gt; Embed\n Set the height of the thumbnail image\nSynonyms:\nglyph/builders/embed.thumbnail_height\nglyph/builders/embed thumbnail_height","url":"glyph/builders/embed.html#thumbnail_height"},{"doc":"glyph/builders/embed","title":"thumbnail_width","content":"pub fn thumbnail_width(e: Embed, width: Int) -&gt; Embed\n Set the width of the thumbnail image\nSynonyms:\nglyph/builders/embed.thumbnail_width\nglyph/builders/embed thumbnail_width","url":"glyph/builders/embed.html#thumbnail_width"},{"doc":"glyph/builders/embed","title":"title","content":"pub fn title(e: Embed, title: String) -&gt; Embed\n Set the title of the embed\nSynonyms:\nglyph/builders/embed.title\nglyph/builders/embed title","url":"glyph/builders/embed.html#title"},{"doc":"glyph/builders/embed","title":"url","content":"pub fn url(e: Embed, url: String) -&gt; Embed\n Set the source URL of the embed\nSynonyms:\nglyph/builders/embed.url\nglyph/builders/embed url","url":"glyph/builders/embed.html#url"},{"doc":"glyph/builders/embed","title":"video","content":"pub fn video(e: Embed, video_url: String) -&gt; Embed\n Set the source URL for a video\nSynonyms:\nglyph/builders/embed.video\nglyph/builders/embed video","url":"glyph/builders/embed.html#video"},{"doc":"glyph/builders/embed","title":"video_height","content":"pub fn video_height(e: Embed, height: Int) -&gt; Embed\n Set the height of the embedded video\nSynonyms:\nglyph/builders/embed.video_height\nglyph/builders/embed video_height","url":"glyph/builders/embed.html#video_height"},{"doc":"glyph/builders/embed","title":"video_width","content":"pub fn video_width(e: Embed, width: Int) -&gt; Embed\n Set the width of the embedded video\nSynonyms:\nglyph/builders/embed.video_width\nglyph/builders/embed video_width","url":"glyph/builders/embed.html#video_width"},{"doc":"glyph/builders/embed","title":"glyph/builders/embed","content":" This contains the builder functions for constructing an Embed\n \n ## Example\n \n ```gleam\n embed.new()\n |&gt; embed.title(&quot;Example embed&quot;)\n |&gt; embed.description(&quot;Example description&quot;)\n ```","url":"glyph/builders/embed.html"},{"doc":"glyph/builders/message","title":"content","content":"pub fn content(\n  m: MessagePayload,\n  content: String,\n) -&gt; MessagePayload\n Set the content of the message\nSynonyms:\nglyph/builders/message.content\nglyph/builders/message content","url":"glyph/builders/message.html#content"},{"doc":"glyph/builders/message","title":"embed","content":"pub fn embed(m: MessagePayload, e: Embed) -&gt; MessagePayload\n Add an Embed to the message\nSynonyms:\nglyph/builders/message.embed\nglyph/builders/message embed","url":"glyph/builders/message.html#embed"},{"doc":"glyph/builders/message","title":"is_tts","content":"pub fn is_tts(m: MessagePayload) -&gt; MessagePayload\n Sets the `tts` flag to `True` for Text-to-Speech messages\nSynonyms:\nglyph/builders/message.is_tts\nglyph/builders/message is_tts","url":"glyph/builders/message.html#is_tts"},{"doc":"glyph/builders/message","title":"mentions_everyone","content":"pub fn mentions_everyone(m: MessagePayload) -&gt; MessagePayload\n If your message contains @everyone, this must be set\nSynonyms:\nglyph/builders/message.mentions_everyone\nglyph/builders/message mentions_everyone","url":"glyph/builders/message.html#mentions_everyone"},{"doc":"glyph/builders/message","title":"mentions_roles","content":"pub fn mentions_roles(m: MessagePayload) -&gt; MessagePayload\n If your message contains a mention of a role, this must be set\nSynonyms:\nglyph/builders/message.mentions_roles\nglyph/builders/message mentions_roles","url":"glyph/builders/message.html#mentions_roles"},{"doc":"glyph/builders/message","title":"mentions_users","content":"pub fn mentions_users(m: MessagePayload) -&gt; MessagePayload\n If your message contains a mention of a user, this must be set\nSynonyms:\nglyph/builders/message.mentions_users\nglyph/builders/message mentions_users","url":"glyph/builders/message.html#mentions_users"},{"doc":"glyph/builders/message","title":"new","content":"pub fn new() -&gt; MessagePayload\n Construct a new, empty MessagePayload\nSynonyms:\nglyph/builders/message.new\nglyph/builders/message new","url":"glyph/builders/message.html#new"},{"doc":"glyph/builders/message","title":"reply_to","content":"pub fn reply_to(\n  m: MessagePayload,\n  msg: Message,\n) -&gt; MessagePayload\n Sets the message to be a reply to a given Message\nSynonyms:\nglyph/builders/message.reply_to\nglyph/builders/message reply_to","url":"glyph/builders/message.html#reply_to"},{"doc":"glyph/builders/message","title":"stickers","content":"pub fn stickers(\n  m: MessagePayload,\n  sticker_ids: List(String),\n) -&gt; MessagePayload\n Send a sticker with your message (maximum of 3)\n \n Note: since you cannot extract sticker IDs from the Discord\n application right now, you will need to wait for Glyph\n to implement the proper API interactions.\nSynonyms:\nglyph/builders/message.stickers\nglyph/builders/message stickers","url":"glyph/builders/message.html#stickers"},{"doc":"glyph/builders/message","title":"suppress_notifications","content":"pub fn suppress_notifications(\n  m: MessagePayload,\n) -&gt; MessagePayload\n Sets a flag to suppress notifications for this message\nSynonyms:\nglyph/builders/message.suppress_notifications\nglyph/builders/message suppress_notifications","url":"glyph/builders/message.html#suppress_notifications"},{"doc":"glyph/builders/message","title":"glyph/builders/message","content":" This contains the builder functions for constructing a MessagePayload\n \n ## Examples\n \n ```gleam\n message.new()\n |&gt; message.content(&quot;Example message&quot;)\n ```\n \n ```gleam\n let example_embed =\n  embed.new()\n  |&gt; embed.title(&quot;Example embed&quot;)\n  |&gt; embed.description(&quot;Example description&quot;)\n \n message.new()\n |&gt; message.embed(example_embed)\n ```","url":"glyph/builders/message.html"},{"doc":"glyph/clients/bot","title":"BotError","content":"pub type BotError {\n  BotError(message: String)\n}\n Generic bot error\nBotError(message: String)\n\n\nSynonyms:\nglyph/clients/bot.BotError\nglyph/clients/bot BotError","url":"glyph/clients/bot.html#BotError"},{"doc":"glyph/clients/bot","title":"initialize","content":"pub fn initialize(bot: BotClient) -&gt; Result(BotClient, BotError)\n Initialize a supervisor that manages the WebSocket process (aka the bot)\nSynonyms:\nglyph/clients/bot.initialize\nglyph/clients/bot initialize","url":"glyph/clients/bot.html#initialize"},{"doc":"glyph/clients/bot","title":"new","content":"pub fn new(\n  token: String,\n  client_url: String,\n  client_version: String,\n) -&gt; BotClient\n Construct a new BotClient\nSynonyms:\nglyph/clients/bot.new\nglyph/clients/bot new","url":"glyph/clients/bot.html#new"},{"doc":"glyph/clients/bot","title":"on_message_create","content":"pub fn on_message_create(\n  bot: BotClient,\n  callback: fn(BotClient, Message) -&gt; Result(Nil, DiscordError),\n) -&gt; BotClient\n Register a handler for the MESSAGE_CREATE gateway event.\n \n The callback function must accept a `BotClient` as its first argument,\n and is provided a `Message` argument as part of the `MESSAGE_CREATE` event.\nSynonyms:\nglyph/clients/bot.on_message_create\nglyph/clients/bot on_message_create","url":"glyph/clients/bot.html#on_message_create"},{"doc":"glyph/clients/bot","title":"send","content":"pub fn send(\n  bot: BotClient,\n  channel_id: String,\n  message: MessagePayload,\n) -&gt; Result(Response(String), Error)\n Send a message to a channel.\n \n For constructing a message, see [the message builder](https://hexdocs.pm/glyph/glyph/builders/message.html).\n For constructing an embed, see [the embed builder](https://hexdocs.pm/glyph/glyph/builders/embed.html).\nSynonyms:\nglyph/clients/bot.send\nglyph/clients/bot send","url":"glyph/clients/bot.html#send"},{"doc":"glyph/clients/bot","title":"set_intents","content":"pub fn set_intents(\n  b: BotClient,\n  intents: List(GatewayIntent),\n) -&gt; BotClient\n Register intents for your bot\nSynonyms:\nglyph/clients/bot.set_intents\nglyph/clients/bot set_intents","url":"glyph/clients/bot.html#set_intents"},{"doc":"glyph/clients/bot","title":"glyph/clients/bot","content":" This contains the client with functions specifically made for Bot users.","url":"glyph/clients/bot.html"}]);